<?php

/**
 * Description of premiumize
 * @author     premiumize.me <leo@wb5.me>
 * @copyright  2019
 * @version     2.0.2
 */
class SynoFileHostingPremiumize
{
  private static $PREMIUMIZE_API_URL = "https://www.premiumize.me/api";
  private static $LOG_FILE_PATH = "/tmp/SynoFileHostingPremiumize.txt";
  private static $MODULE_INFO = array(
    "name" => "premiumize.me",
    "hostprefix" => "ul.to,uploaded.net,uploaded.to,mediafire.com,turbo-bit.net,turbobit.net,turbo.to,turbobit.cc,1fichier.com,alterupload.com,cjoint.net,dl4free.com,tenvoi.com,pjointe.com,megadl.fr,piecejointe.net,mesfichiers.org,dfichiers.com,desfichiers.com,filer.net,cloudtime.ch,cloudtime.co,cloudtime.sx,cloudtime.to,cloudtime.eu,zippyshare.com,brazzers.com,brazzersnetwork.com,flashx.tv,flashx.pw,kink.com,fireget.com,file.al,hitfile.net,filenext.com,mofos.com,uploadboy.com,uploadboy.me,teamskeet.com,wipfiles.net,userscloud.com,filespace.com,nubilefilms.com,mexashare.com,mx-sh.net,mexa.sh,clicknupload.org,vidlox.me,vidlox.tv,ulozto.net,uloz.to,ulozto.sk,zachowajto.pl,hulkshare.com,vidoza.net,ubiqfile.com,spicyfile.com,isra.cloud,israbox.ch,isrbx.net,wdupload.com,xubster.com,worldbytez.com,ddfnetwork.com,ddfbusty.com/,mega.nz,mega.co.nz,modsbase.com,filestore.to,ddl.to",
    "displayname" => "Premiumize.me",
    "version" => "2.0.3",
    "authentication" => "yes",
    "module" => "SynoFileHostingPremiumize.php",
    "class" => "SynoFileHostingPremiumize",
    "description" => "Premium account supported."
  );
  private $LogEnabled = false;
  private $LogFile = -1;

  private $Url;
  private $Username;
  private $Password;
  private $HostInfo = null;
  protected $InfoPath = "/dev/null";

  public function __construct($Url, $Username, $Password, $HostInfo) {
    $this->Url = $Url;
    $this->Username = $Username;
    $this->Password = $Password;
    $this->HostInfo = $HostInfo; // not used
    $this->InfoPath = __DIR__.DIRECTORY_SEPARATOR.'INFO';
  }

  public function __destruct()
  {
    if (is_resource($this->LogFile))
    {
      fclose($this->LogFile);
    }
  }

  private function log($string)
  {
    if ($this->LogEnabled)
    {
      if ($this->LogFile === -1)
      {
        $this->LogFile = @fopen(self::$LOG_FILE_PATH, "ab+");
      }
      if (is_resource($this->LogFile))
      {
        fwrite($this->LogFile, $string . "\n");
      }
    }
  }

  private function request($endpoint, $args = []){

    $args["customer_id"] = $this->Username;
    $args["pin"] = $this->Password;
    $url = self::$PREMIUMIZE_API_URL.$endpoint."?".http_build_query($args);

    // init curl
    $curl = curl_init();
    curl_setopt($curl, CURLOPT_URL, $url);
    curl_setopt($curl, CURLOPT_CONNECTTIMEOUT, DOWNLOAD_TIMEOUT);
    curl_setopt($curl, CURLOPT_TIMEOUT, DOWNLOAD_TIMEOUT);
    curl_setopt($curl, CURLOPT_USERAGENT, DOWNLOAD_STATION_USER_AGENT);
    curl_setopt($curl, CURLOPT_RETURNTRANSFER, TRUE);
    curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, FALSE);

    $data = null;
    if (($result = curl_exec($curl)) !== FALSE)
    {
      $data = json_decode($result);
    }

    curl_close($curl);
    return $data;
  }

  public function GetDownloadInfo() {
    $this->log(__METHOD__);

    if (strpos($this->Url, 'https://www.premiumize.me/file?id=') !== false) {
        $id = substr($this->Url, strpos($this->Url, '=') + 1);
        $data = $this->request("/item/details", ["id" => $id]);

        $ret = array();
        if ($data && isset($data->link) && isset($data->name)) {
            $ret[DOWNLOAD_URL] = $data->link;
            $ret[DOWNLOAD_FILENAME] = $data->name;
            $this->log("Successfully get download link: " . $this->Url);
        } else {
            $this->log("Error getting download link: " . $this->Url . ". Error: " . print_r($data, true));
        }
    } else {
        $data = $this->request("/transfer/directdl", ["src" => $this->Url]);

        $ret = array();
        if ($data && $data->status == 'success' && isset($data->location)) {
            $ret[DOWNLOAD_URL] = $data->location;
            $ret[DOWNLOAD_FILENAME] = $data->filename;
            $this->log("Successfully get download link: " . $this->Url);
        } else {
            $this->log("Error getting download link: " . $this->Url . ". Error: " . print_r($data, true));
        }
    }

    return $ret;
  }

  public function Verify()
  {
    $this->log(__METHOD__);
    $data = $this->request("/account/info");
      if ($data && $data->status == "success" && $data->premium_until != false)
      {
        $ret = USER_IS_PREMIUM;
        if($this->UpdateInfoFile()){
            $this->log("Successfully Updated File ".$this->InfoPath);
        }

      } else {
        $ret = LOGIN_FAIL;
      }

      return $ret;
  }

  private function UpdateInfoFile() {

    if(!is_file($this->InfoPath)) {
      $this->log("Update-Error: file not found: ".$this->InfoPath);
      return false;
    }
    $data = $this->request("/services/list");
    if ($data && isset($data->directdl) && count($data->directdl) > 0){

      $hostprefix = [];
      foreach($data->directdl as $directdl){
          foreach ($data->aliases->$directdl as $value) {
              $hostprefix[] = $value;
          }
      }

      $hostprefixStr = join(',', $hostprefix) . ',premiumize.me';
      $info = (Object)self::$MODULE_INFO;
      $info->hostprefix = $hostprefixStr;

      $fp = @fopen($this->InfoPath, "w");
      if(!is_resource($fp)) {

        $this->log("Update-Warning: could not open file for writing: ".$this->InfoPath.". now trying to delete and create a new one");

        if(!unlink($this->InfoPath)) {
          $this->log("Update-Error: could not remove old INFO file.");
          return false;
        }

        $fp = @fopen($this->InfoPath,'w');
        if(!is_resource($fp)) {
          $this->log("Update-Error: could not write INFO file. giving up.");
          return false;
        }

      }

      if(!fwrite($fp,json_encode($info))) {
        $this->log("Update-Error: could not write to file ".$this->InfoPath);
        return false;
      }

      @chmod($this->InfoPath,0666);
      @fclose($fp);

      return true;

    } else {

      $this->log("Update-Error: could not get hoster list from API. Error: ".print_r($data,true));
      return false;
    }
  }

}

?>
